@@ -2,6 +2,9 @@ export2csv<-function(x, file, which.table="descr", sep=",", nmax = TRUE, ...){
 
   if (!inherits(x,"createTable"))
     stop("x must be of class 'createTable'")
+    
+  if (inherits(x,"cbind.createTable"))
+    stop("x cannot be of class 'cbind.createTable'")        
 
   if (sep!="," & sep!=";")
     stop("sep must be ',' or ';'")
